@@ -10,7 +10,6 @@
 
 #include "draghelper.h"
 #include "mousehelper.h"
-#include "preview.h"
 #include "resultsmodel.h"
 #include "sourcesmodel.h"
 
@@ -25,7 +24,6 @@ void QmlPlugins::registerTypes(const char *uri)
 {
     qmlRegisterType<Milou::SourcesModel>(uri, 0, 1, "SourcesModel");
     qmlRegisterType<Milou::ResultsModel>(uri, 0, 3, "ResultsModel");
-    qmlRegisterType<Milou::Preview>(uri, 0, 1, "Preview");
     qmlRegisterType<Milou::DragHelper>(uri, 0, 2, "DragHelper");
     qmlRegisterSingletonType<Milou::MouseHelper>(uri, 0, 1, "MouseHelper", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return new Milou::MouseHelper();
