@@ -1,22 +1,8 @@
 /*
  * This file is part of the KDE Milou Project
- * Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
+ * SPDX-FileCopyrightText: 2013 Vishesh Handa <me@vhanda.in>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
 
@@ -167,6 +153,7 @@ int SourcesModel::queryLimit() const
     return m_queryLimit;
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 81)
 QString SourcesModel::runner() const
 {
     return m_runner;
@@ -203,6 +190,7 @@ QIcon SourcesModel::runnerIcon() const
 
     return singleRunner->icon();
 }
+#endif
 
 void SourcesModel::setQueryLimit(int limit)
 {
